<a href="https://www.islas.org.mx/"><img src="https://www.islas.org.mx/img/logo.svg" align="right" width="256" /></a>
[![codecov](https://codecov.io/gh/IslasGECI/kaggle/graph/badge.svg?token=RY807ST1T1)](https://codecov.io/gh/IslasGECI/kaggle)
![example branch
parameter](https://github.com/IslasGECI/kaggle/actions/workflows/actions.yml/badge.svg)
![licencia](https://img.shields.io/github/license/IslasGECI/kaggle)
![languages](https://img.shields.io/github/languages/top/IslasGECI/kaggle)
![commits](https://img.shields.io/github/commit-activity/y/IslasGECI/kaggle)
![PyPI - Version](https://img.shields.io/pypi/v/kaggle)

# Kaggle
Practice field for Kaggle's competitions.
